@@ -191,42 +191,61 @@ summary.extrafrail <- function (object, ...)
                   ifelse(object$dist == "pe", "piecewise exponential", 
                     object$dist)), " survival function\n", sep = "")
     }
+    if (object$dist.frail == "JSW") {
+        if (uni) 
+            cat("Univariate Jorgensen-Seshadri-Whitmore frailty model with\n", 
+                ifelse(object$dist == "np", "non-parametric", 
+                  ifelse(object$dist == "pe", "piecewise exponential", 
+                    object$dist)), " survival function\n", sep = "")
+        if (bi) 
+            cat("Bivariate Jorgensen-Seshadri-Whitmore frailty model with\n", 
+                ifelse(object$dist == "np", "non-parametric", 
+                  ifelse(object$dist == "pe", "piecewise exponential", 
+                    object$dist)), " survival function\n", sep = "")
+        if (!uni & !bi) 
+            cat("Multivariate Jorgensen-Seshadri-Whitmore frailty model with\n", 
+                ifelse(object$dist == "np", "non-parametric", 
+                  ifelse(object$dist == "pe", "piecewise exponential", 
+                    object$dist)), " survival function\n", sep = "")
+    }
+	aux.par=0
+	if(object$dist.frail=="JSW") aux.par=1
     if (length(object$coefficients) > 1) {
         if (object$dist == "np") {
             cat("-------------------------------------------------------------------------\n")
             cat("Regression Coefficients\n")
-            print(tt[-nrow(tt), , drop = FALSE])
+            print(tt[-c(nrow(tt)-0:aux.par), , drop = FALSE])
             cat("---\n")
             cat("Signif. codes:  0 \"***\" 0.001 \"**\" 0.01 \"*\" 0.05 \".\" 0.1 \" \" 1\n")
             cat("-------------------------------------------------------------------------\n")
             cat("Frailty variance\n")
-            print(tt[nrow(tt), 1:2, drop = FALSE])
+            print(tt[nrow(tt)-aux.par, 1:2, drop = FALSE])
             cat("-------------------------------------------------------------------------\n")
         }
         if (object$dist != "np") {
             if (object$dist == "weibull") {
-                if (nrow(tt) > 3) {
+                if (nrow(tt) > 3+aux.par) {
                   cat("-------------------------------------------------------------------------\n")
                   cat("Regression Coefficients\n")
-                  print(tt[-c(nrow(tt) - 0:2), , drop = FALSE])
+                  print(tt[-c(nrow(tt) - 0:(2+aux.par)), , drop = FALSE])
                   cat("---\n")
                   cat("Signif. codes:  0 \"***\" 0.001 \"**\" 0.01 \"*\" 0.05 \".\" 0.1 \" \" 1\n")
                 }
             }
             if (object$dist == "exponential") {
-                if (nrow(tt) > 2) {
+                if (nrow(tt) > 2+aux.par) {
                   cat("-------------------------------------------------------------------------\n")
                   cat("Regression Coefficients\n")
-                  print(tt[-c(nrow(tt) - 0:1), , drop = FALSE])
+                  print(tt[-c(nrow(tt) - 0:(1+aux.par)), , drop = FALSE])
                   cat("---\n")
                   cat("Signif. codes:  0 \"***\" 0.001 \"**\" 0.01 \"*\" 0.05 \".\" 0.1 \" \" 1\n")
                 }
             }
             if (object$dist == "pe") {
-                if (nrow(tt) > length(object$part) + 1) {
+                if (nrow(tt) > length(object$part) + 1+aux.par) {
                   cat("-------------------------------------------------------------------------\n")
                   cat("Regression Coefficients\n")
-                  print(tt[-c(nrow(tt) - 0:(length(object$part))), 
+                  print(tt[-c(nrow(tt) - 0:(length(object$part)+aux.par)), 
                     , drop = FALSE])
                   cat("---\n")
                   cat("Signif. codes:  0 \"***\" 0.001 \"**\" 0.01 \"*\" 0.05 \".\" 0.1 \" \" 1\n")
@@ -236,13 +255,19 @@ summary.extrafrail <- function (object, ...)
             cat("Parameters of baseline distribution\n")
             ss = ifelse(object$dist == "pe", length(object$par), 
                 ifelse(object$dist == "exponential", 1, 2))
-            print(tt[nrow(tt) - ss:1, 1:2, drop = FALSE])
+            print(tt[nrow(tt) - (ss:1+aux.par), 1:2, drop = FALSE])
             cat("-------------------------------------------------------------------------\n")
             cat("Frailty variance\n")
-            print(tt[nrow(tt), 1:2, drop = FALSE])
+            print(tt[nrow(tt)-aux.par, 1:2, drop = FALSE])
             cat("-------------------------------------------------------------------------\n")
         }
     }
+	if(object$dist.frail=="JSW")
+	{
+            cat("Additional parameters for frailty distribution\n")
+            print(tt[nrow(tt), 1:2, drop = FALSE])
+            cat("-------------------------------------------------------------------------\n")
+	}
     if (length(object$coefficients) == 1) {
         cat("-------------------------------------------------------------------------\n")
         cat("Frailty variance\n")
@@ -252,4 +277,3 @@ summary.extrafrail <- function (object, ...)
     cat(paste("Kendall's tau:", round(object$tau, 4)))
     cat("\n---\n")
 }
-    
\ No newline at end of file
